<?php

namespace Drupal\organization_field\Controller;

use Drupal\Component\Utility\Xss;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Controller\ControllerBase;
use GuzzleHttp\ClientInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Fetches data from the ROR REST API.
 *
 * Populates it in the autocomplete organization field.
 *
 * Reference - https://ror.readme.io/docs/rest-api.
 */
class JsonApiController extends ControllerBase {
  /**
   * A http client.
   */
  protected ClientInterface $httpClient;

  /**
   * The configuration factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a new CustomWidget object.
   */
  public function __construct(ConfigFactoryInterface $config_factory,
        ClientInterface $http_client) {
    $this->configFactory = $config_factory;
    $this->httpClient = $http_client;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): static {
    return new static(
          $container->get('config.factory'),
          $container->get('http_client')
      );
  }

  /**
   * Fetches the specified number of the organizations from ROR API.
   */
  public function handleAutocomplete(Request $request): JsonResponse {
    // Organization field autocomplete
    // Returns [value, label] array of results.
    $results = [];
    $input = $request->query->get('q');

    if (!$input) {
      return new JsonResponse($results);
    }
    $input = Xss::filter($input);

    $config = $this->configFactory->getEditable('organization_field.settings');
    $ror_api = $config->get('ror_api');
    $params = '?query=' . $input;
    $response2 = $this->httpClient->request('GET', $ror_api . $params);
    $json_string = (string) $response2->getBody();
    $json = json_decode($json_string, TRUE);

    $no_of_results = (string) $json['number_of_results'];
    $max_rors_to_display = $config->get('ror_items_depth');

    if ($no_of_results > $max_rors_to_display) {
      $no_of_results = $max_rors_to_display;
    }

    for ($x = 0; $x < $no_of_results; $x++) {
      $name = (string) $json['items'][$x]['name'];
      $results[] = [
        'value' => $name,
        'label' => $name,
      ];
    }

    return new JsonResponse($results);
  }

}
